==> libreoffice-4.4.2.2.tar.xz: libreoffice-4.4.2.2/svtools/source/misc/dialogclosedlistener.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <svtools/dialogclosedlistener.hxx>


namespace svt
{


    using namespace ::com::sun::star::lang;
    using namespace ::com::sun::star::uno;
    using namespace ::com::sun::star::ui::dialogs;


    //= DialogClosedListener


    DialogClosedListener::DialogClosedListener()
    {
    }

    // XDialogClosedListener methods
    void SAL_CALL DialogClosedListener::dialogClosed( const DialogClosedEvent& aEvent ) throw (RuntimeException, std::exception)
    {
        if ( m_aDialogClosedLink.IsSet() )
        {
            ::com::sun::star::ui::dialogs::DialogClosedEvent aEvt( aEvent );
            m_aDialogClosedLink.Call( &aEvt );
        }
    }

    // XEventListener methods
    void SAL_CALL DialogClosedListener::disposing( const EventObject& ) throw(RuntimeException, std::exception)
    {
        m_aDialogClosedLink = Link();
    }


}   // namespace svt



/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice-5.0.5.2.tar.xz: libreoffice-5.0.5.2/svtools/source/misc/dialogclosedlistener.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <svtools/dialogclosedlistener.hxx>


namespace svt
{


    using namespace ::com::sun::star::lang;
    using namespace ::com::sun::star::uno;
    using namespace ::com::sun::star::ui::dialogs;


    //= DialogClosedListener


    DialogClosedListener::DialogClosedListener()
    {
    }

    // XDialogClosedListener methods
    void SAL_CALL DialogClosedListener::dialogClosed( const DialogClosedEvent& aEvent ) throw (RuntimeException, std::exception)
    {
        if ( m_aDialogClosedLink.IsSet() )
        {
            ::com::sun::star::ui::dialogs::DialogClosedEvent aEvt( aEvent );
            m_aDialogClosedLink.Call( &aEvt );
        }
    }

    // XEventListener methods
    void SAL_CALL DialogClosedListener::disposing( const EventObject& ) throw(RuntimeException, std::exception)
    {
        m_aDialogClosedLink = Link<>();
    }


}   // namespace svt



/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
